@@ -1,8 +1,10 @@
+//! Processors pipeline
 use super::config::{Config, ProcessorConfig};
 use super::pool::Pool;
 use super::processor::Processor;
 use crate::core::LennaImage;
 
+/// Pipeline to serially run processors
 pub struct Pipeline {
     config: Config,
     pool: Pool,
@@ -44,3 +46,15 @@ impl Default for Pipeline {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn default() {
+        let pipeline = Pipeline::default();
+        let mut image = Box::new(LennaImage::default());
+        pipeline.run(&mut image).unwrap();
+    }
+}
